@@ -15,9 +15,15 @@ def get_default(username):
             defaults = ast.literal_eval(defaults)
 
     except Exception as e:  # the first time using EpiBOX Core, there will be no default file
-        defaults = ast.literal_eval(
-            pkg_resources.read_text(common, "default_args.json")
-        )
+        defaults = {
+            "initial_dir": "EpiBOX Core",
+            "fs": 1000,
+            "channels": [],
+            "devices_mac": {"MAC1": "12:34:56:78:91:10", "MAC2": "01:19:87:65:43:21"},
+            "save_raw": "true",
+            "patient_id": "default",
+            "service": "Bitalino",
+        }
 
         with open(
             "/home/{}/Documents/epibox/args.json".format(username), "w+"
